@@ -1,7 +1,7 @@
 package Email::Sender::Success;
-use Mouse;
+use Moose;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 =head1 NAME
 
@@ -10,5 +10,5 @@ Email::Sender::Success - the result of successfully sending mail
 =cut
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
