@@ -1,8 +1,8 @@
 package Email::Sender::Success::Partial;
-use Mouse;
+use Moose;
 extends 'Email::Sender::Success';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 =head1 NAME
 
@@ -25,5 +25,5 @@ has failure => (
 );
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
