@@ -1,8 +1,8 @@
 package Email::Sender::Transport::Failable;
-use Mouse;
+use Moose;
 extends 'Email::Sender::Transport::Wrapper';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 =head1 NAME
 
@@ -36,5 +36,5 @@ around send_email => sub {
 };
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
